@@ -1,15 +1,8 @@
 # Mask > Mask from alpha channel
 # (fr) Masque > Masque depuis canal alpha
-# (es) Máscara > Máscara desde canal alpha
-# (de) Maske > Maske vom Alphakanal
 from lazpaint import image, layer, filters, selection, dialog
 
-translation = dialog.select_translation(
-  en = {"Mask" : "Mask"}, 
-  fr = {"Mask": "Masque"}, 
-  es = {"Mask": "Máscara"}, 
-  de = {"Mask": "Maske"}
-  )
+translation = dialog.translate_dict(["Mask"])
 
 image.do_begin()
 
